@@ -18,11 +18,10 @@ ExtractGainMapCommand::ExtractGainMapCommand()
 
 avifResult ExtractGainMapCommand::Run() {
   DecoderPtr decoder(avifDecoderCreate());
-  if (decoder == NULL) {
+  if (decoder == nullptr) {
     return AVIF_RESULT_OUT_OF_MEMORY;
   }
-  decoder->enableDecodingGainMap = true;
-  decoder->ignoreColorAndAlpha = true;
+  decoder->imageContentToDecode = AVIF_IMAGE_CONTENT_GAIN_MAP;
 
   avifResult result =
       ReadAvif(decoder.get(), arg_input_filename_, /*ignore_profile=*/true);
